# Step 3: Collect Data
### On this page
  * [Collect Data from Experts](https://help.sap.com/docs/leanix/ea/application-modernization-collect-data#collect-data-from-experts)
  * [Use To-Dos to Manage Data Collection](https://help.sap.com/docs/leanix/ea/application-modernization-collect-data#use-to-dos-to-manage-data-collection)
  * [Collect Data from Integrations](https://help.sap.com/docs/leanix/ea/application-modernization-collect-data#collect-data-from-integrations)


Data collection is crucial for getting comprehensive insights into your architecture. You can expedite the process with surveys and integrations.
The next step is to collect detailed data. Keep in mind that information gathering is often the most time-consuming phase, because it requires input from various stakeholders. Surveys and integrations can streamline your data collection process and reduce the time needed to achieve the required data quality. Use to-dos to keep everyone on track.
